import cv2
import numpy as np
import click


def red_green(image):
    print("Change colors...")
    for i in range(image.shape[0]):
        for j in range(image.shape[1]):
            image[i][j] = np.array([image[i][j][0], image[i][j][2],
                                    image[i][j][1]])

    return image


def green_blue(image):
    print("Change colors...")
    for i in range(image.shape[0]):
        for j in range(image.shape[1]):
            image[i][j] = np.array([image[i][j][1], image[i][j][0],
                                    image[i][j][2]])

    return image


def blue_red(image):
    print("Change colors...")
    for i in range(image.shape[0]):
        for j in range(image.shape[1]):
            image[i][j] = np.array([image[i][j][2], image[i][j][1],
                                    image[i][j][0]])

    return image


@click.command()
@click.option("-i", "--image", help="Path to image. Can be a relative path.")
@click.option("-c", "--changer", default="red-green", help="Specify the changer. Can be red-green, green-blue or blue-red")
@click.option("-r", "--result", default="new.jpg", help="Specify the images name.")
def main(image, changer, result):
    print("Load image...")
    img = cv2.imread(image)
    print("Determine changer...")
    if changer == "red-green":
        new_img = red_green(img)
        cv2.imwrite(result, new_img)
        print("Successful.")
    elif changer == "green-blue":
        new_img = green_blue(img)
        cv2.imwrite(result, new_img)
        print("Successful.")
    elif changer == "blue-red":
        new_img = blue_red(img)
        cv2.imwrite(result, new_img)
        print("Successful.")
    else:
        print("Changer does not exist.")


if __name__ == "__main__":
    main()



from setuptools import setup

setup(
    name='color-changer',
    version='1.0.5',
    packages=['colorchanger', ],
    license='MIT',
    description='Reads in an image and swap specified colors ',
    long_description=open('README.rst').read(),
    author='Florian Dahlitz',
    author_email='f2dahlitz@freenet.de',
    url='https://github.com/DahlitzFlorian/python-color-changer',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords='color changer color-changer opencv numpy',
    install_requires=[
        'click',
        'numpy'
    ],
)